==> libwpd-0.6.6.tar.bz2: libwpd-0.6.6/src/lib/WP6FillStylePacket.h <==
/* libwpd2
 * Copyright (C) 2002 William Lachance (william.lachance@sympatico.ca)
 * Copyright (C) 2002 Marc Maurer (j.m.maurer@student.utwente.nl)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP6FILLSTYLEPACKET_H
#define WP6FILLSTYLEPACKET_H
#include "WP6PrefixDataPacket.h"
#include "WP6FileStructure.h"
#include "WP6LLListener.h"

struct _RGBSColor;
typedef struct _RGBSColor RGBSColor; 

class WP6FillStylePacket : public WP6PrefixDataPacket
{
public:
	WP6FillStylePacket(GsfInput *input, int id, guint32 dataOffset, guint32 dataSize);
	virtual ~WP6FillStylePacket();
	virtual void _readContents(GsfInput *input);
	virtual void parse(WP6LLListener *llListener) const {}
	const RGBSColor * getFgColor() const { return &m_fgColor; }
	const RGBSColor * getBgColor() const { return &m_bgColor; }
private:              
	RGBSColor m_fgColor;
	RGBSColor m_bgColor;
};
#endif /* WP6FILLSTYLEPACKET_H */

==> libwpd_0.9.4.orig.tar.bz2: libwpd-0.9.4/src/lib/WP6FillStylePacket.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libwpd
 * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
 * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP6FILLSTYLEPACKET_H
#define WP6FILLSTYLEPACKET_H
#include "WP6PrefixDataPacket.h"
#include "WP6FileStructure.h"
#include "libwpd_internal.h"

struct _RGBSColor;
typedef struct _RGBSColor RGBSColor;

class WP6FillStylePacket : public WP6PrefixDataPacket
{
public:
	WP6FillStylePacket(WPXInputStream *input, WPXEncryption *encryption, int id, uint32_t dataOffset, uint32_t dataSize);
	~WP6FillStylePacket();
	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
	void parse(WP6Listener * /* listener */) const {}
	const RGBSColor *getFgColor() const
	{
		return &m_fgColor;
	}
	const RGBSColor *getBgColor() const
	{
		return &m_bgColor;
	}
private:
	RGBSColor m_fgColor;
	RGBSColor m_bgColor;
};
#endif /* WP6FILLSTYLEPACKET_H */
/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
